
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: pytest-iters:package

from setuptools import setup

setup(**{
    'author': 'Ryan Northey',
    'author_email': 'ryan@synca.io',
    'description': 'A contextmanager pytest fixture for handling multiple mock iters',
    'entry_points': {
        'pytest11': [
            'iters=pytest_iters',
        ],
    },
    'install_requires': (
    ),
    'license': 'Apache Software License 2.0',
    'long_description': """============
pytest-iters
============


Installation
------------

You can install "pytest-iters" via ``pip``

.. code-block:: console

    $ pip install pytest-iters


License
-------

Distributed under the terms of the Apache Software License 2.0 license, "pytest-iters" is free and open source software
""",
    'maintainer': 'Ryan Northey',
    'maintainer_email': 'ryan@synca.io',
    'name': 'pytest-iters',
    'namespace_packages': (
    ),
    'package_data': {
        'pytest_iters': (
            'py.typed',
        ),
    },
    'packages': (
        'pytest_iters',
    ),
    'url': 'https://github.com/envoyproxy/pytooling/tree/main/pytest-iters',
    'version': '0.0.3',
})
